@@ -30,9 +30,7 @@ pub struct SlackClientSession<'a, SCHC>
 where
     SCHC: SlackClientHttpConnector + Send,
 {
-    pub http_api: SlackClientHttpSessionApi<'a, SCHC>,
-    client: &'a SlackClient<SCHC>,
-    token: &'a SlackApiToken,
+    pub http_session_api: SlackClientHttpSessionApi<'a, SCHC>,
 }
 
 #[derive(Debug)]
@@ -212,11 +210,7 @@ where
             token,
         };
 
-        SlackClientSession {
-            client: self,
-            token,
-            http_api: http_session_api,
-        }
+        SlackClientSession { http_session_api }
     }
 }
 
